noteFiles = {}
previousFileInfos = {}
currentPath = basePath or "/sdcard/" -- تأكد من ضبط currentPath حسب الحاجة

local handler = Handler()
local runnable

function naturalSort(a, b)
  local function padnum(d) return ("%03d"):format(tonumber(d)) end
  a = a:gsub("%d+", padnum)
  b = b:gsub("%d+", padnum)
  return a:lower() < b:lower()
end

function refreshNotes()
  local n, f = getNotes(currentPath)
  local fileInfos = {}

  for i = 1, #n do
    local filePath = f[i]
    local file = File(filePath)
    local lastMod = file.lastModified()
    table.insert(fileInfos, {name = n[i], path = filePath, time = lastMod})
  end

  table.sort(fileInfos, function(a, b)
    if a.time == b.time then
      return naturalSort(a.name, b.name)
    else
      return a.time < b.time
    end
  end)

  local isUpdated = false
  if #fileInfos ~= #previousFileInfos then
    isUpdated = true
  else
    for i = 1, #fileInfos do
      if fileInfos[i].time ~= previousFileInfos[i].time or fileInfos[i].name ~= previousFileInfos[i].name then
        isUpdated = true
        break
      end
    end
  end

  if isUpdated or (#fileInfos == 0 and notesAdapter.getCount() == 0) then
    notesAdapter.clear()
    noteFiles = {}
    if #fileInfos == 0 then
      notesAdapter.add(T.no_notes)
    else
      for i, info in ipairs(fileInfos) do
        local displayText = string.format(
          "%s. %s. %d %s %d. %s. %d %s. %s",
          info.name,
          T.local_note or "",
          i, T.of,
          #fileInfos,
          T.total,
          #fileInfos, T.items,
          T.in_table
        )
        notesAdapter.add(displayText)
        table.insert(noteFiles, info.path)
      end
    end
    notesAdapter.notifyDataSetChanged()
    previousFileInfos = fileInfos
  end
end

function browseFolders(startPath)
  local folders = getFolders(startPath)
  local names = {T.choose_folder}
  table.sort(folders)
  for _, v in ipairs(folders) do
    table.insert(names, v)
  end
  AlertDialog.Builder(activity)
    .setTitle(T.choose_folder)
    .setAdapter(ArrayAdapter(activity, android.R.layout.simple_list_item_1, names),
      function(dialog, which)
        if which == 0 then
          if currentPath ~= basePath then
            currentPath = File(currentPath).getParent() .. "/"
            refreshNotes()
          end
        else
          currentPath = startPath .. folders[which] .. "/"
          refreshNotes()
        end
      end)
    .setNegativeButton(T.close, nil)
    .show()
end

function startAutoRefresh()
  runnable = Runnable{
    run = function()
      refreshNotes()
      handler.postDelayed(runnable, 1000)
    end
  }
  handler.post(runnable)
end