local function getSystemLanguage()
  local lang = Locale.getDefault().getLanguage()
  if Build.VERSION.SDK_INT >= 24 then
    lang = Resources.getSystem().getConfiguration().getLocales().get(0).getLanguage()
  else
    lang = Resources.getSystem().getConfiguration().locale:getLanguage()
  end
  return lang
end

local function convertToArabicNumbers(num)
  local arabicNumbers = {"٠", "١", "٢", "٣", "٤", "٥", "٦", "٧", "٨", "٩"}
  return (tostring(num):gsub("%d", function(digit)
    return arabicNumbers[tonumber(digit) + 1]
  end))
end

 local systemLang = getSystemLanguage()
systemLang = systemLang:match("^[a-z]+")


local days, months, useArabicNumbers
if systemLang == "ar" then
  days = {"الأحد", "الإثنين", "الثلاثاء", "الأربعاء", "الخميس", "الجمعة", "السبت"}
  months = {"يناير", "فبراير", "مارس", "أبريل", "مايو", "يونيو", "يوليو", "أغسطس", "سبتمبر", "أكتوبر", "نوفمبر", "ديسمبر"}
  useArabicNumbers = true
elseif systemLang == "es" then
  days = {"domingo", "lunes", "martes", "miércoles", "jueves", "viernes", "sábado"}
  months = {"enero", "febrero", "marzo", "abril", "mayo", "junio", "julio", "agosto", "septiembre", "octubre", "noviembre", "diciembre"}
  useArabicNumbers = false
elseif systemLang == "zh" then
  days = {"星期日", "星期一", "星期二", "星期三", "星期四", "星期五", "星期六"}
  months = {"一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月"}
  useArabicNumbers = false
else
  days = {"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"}
  months = {"January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"}
  useArabicNumbers = false
end

local function formatDateTime(speakDay, speakDate, speakTime)
  local dayOfWeek = days[tonumber(os.date("%w")) + 1]
  local day = tostring(tonumber(os.date("%d")))
  local month = months[tonumber(os.date("%m"))]
  local year = os.date("%Y")
  local hour = os.date("%I")
  local minute = os.date("%M")
  local second = os.date("%S")
  local am_pm = os.date("%p") == "AM" and (systemLang == "ar" and "ص" or "AM") or (systemLang == "ar" and "م" or "PM")

  local rawHour, rawMinute, rawSecond = hour, minute, second

  if useArabicNumbers then
    day = convertToArabicNumbers(day)
    year = convertToArabicNumbers(year)
    hour = convertToArabicNumbers(hour)
    minute = convertToArabicNumbers(minute)
    second = convertToArabicNumbers(second)
  end

  local parts = {}
  if speakDay then table.insert(parts, dayOfWeek) end
  if speakDate then table.insert(parts, string.format("%s %s %s", day, month, year)) end
  if speakTime then table.insert(parts, string.format("%s:%s:%s %s", hour, minute, second, am_pm)) end

  local separator = systemLang == "ar" and "، " or ", "
  local fullDate = table.concat(parts, separator)

  local dayAndDate = string.format("%s%s%s %s", dayOfWeek, separator, day, month)
  local dateAndYear = string.format("%s %s", day, month) .. separator .. year
  local dateOnly = string.format("%s %s", day, month)

  local time = string.format("%s:%s %s", hour, minute, am_pm)
  local timeSec = string.format("%s:%s:%s %s", hour, minute, second, am_pm)

  return fullDate, dayAndDate, dateAndYear, dateOnly, time, timeSec
end

local speakDay = true
local speakDate = true
local speakTime = false

currentDate, dayAndDate, dateAndYear, dateOnly, time, timeSec = formatDateTime(speakDay, speakDate, speakTime)
